AlternativeSyntax

Type Alias AlternativeSyntax 

pub type AlternativeSyntax<T> = StorageMap<_GeneratedPrefixForStorageAlternativeSyntax<T>, Blake2_128Concat, u32, u32>;
In all of these examples, we chose a syntax where the storage item is defined using the explicit generic syntax (X = Y). Alternatively:

Storage type is StorageMap with key type u32 and value type u32.

Aliased Type

pub struct AlternativeSyntax<T>(/* private fields */);